import QtQuick 2.3
import Fly.Components 1.0

FlyPage {
    id: contactInfoPage

    property var contact
    property var confirmFunction
    property string photoPath

    title: qsTr("Contact info")
    titleImage.imagePath: "qrc:/images/contact.png"
    titleImage.imageColorEnabled: false
    titleImage.imageShadow: false
    leftMargin: parent ? parent.width * root.pageMargin : 0
    topMargin: parent ? parent.height * root.pageMargin : 0
    okFunction: saveContact
    cancelFunction: clearMemory

    function init(contact, contactText) {
        contactInfoPage.contact = contact
        photoButton.source = "image://ContactImageProvider/" + (contact ? contact.id : "unknown")
        photoPath = ""

        contactPropertyList.init(contact, contactText)
    }

    function saveContact() {
        contactPropertyList.saveYourself()

        var contact = contactInfoPage.contact
        if(!contact)
            contact = db.getContact()

        contact.name = contactPropertyList.nameText
        contact.surname = contactPropertyList.surnameText
        contact.middlename = contactPropertyList.middlenameText
        contact.organization = contactPropertyList.organizationText
        contact.dateOfBirth = contactPropertyList.dateOfBirthText
        contact.comment = contactPropertyList.comments
        contact.phoneList = contactPropertyList.phoneList
        contact.phoneGroupList = contactPropertyList.phoneNameList
        contact.emailList = contactPropertyList.emails
        contact.emailGroupList = contactPropertyList.emailNames
        contact.addressList = contactPropertyList.addresses
        contact.addressGroupList = contactPropertyList.addressNames
        contact.linkList = contactPropertyList.links

        if(contactInfoPage.contact) {
            db.updateContact(contact)
        } else {
            db.addContact(contact)
        }

        if(photoPath !== "")
            root.setContactPhoto(contact.id, photoPath)

        if(confirmFunction) confirmFunction(contact.id)

        clearMemory()
    }

    function clearMemory() {
        if(contact)
            contact.deleteLater()
    }

    Item {
        id: backgroundItem
        anchors.fill: centerRect;

        readonly property bool horizontal: width > height + height * 0.1
        readonly property real margin: 5 * dpiRatio

        Loader {
            id: fileDialogLoader
            anchors.fill: parent
            active: false
            sourceComponent: Component {
                FlyFileDialog {
                    onFileChosen: {
                        if(fileName !== "") {
                            if(debug) console.log("File chosen: ", fileName)

                            photoButton.source = "file://" + fileName
                            contactInfoPage.photoPath = fileName
                        }
                    }
                }
            }
        }

        FlyPhotoButton {
            id: photoButton
            width: backgroundItem.horizontal ? parent.width * 0.5 - backgroundItem.margin : parent.width
            height: backgroundItem.horizontal ? parent.height : parent.height * 0.5 - backgroundItem.margin
            margins: 0

            function selectMenu(index) {
                if(index === 0) {
                    if(debug) console.log("Launching camera app...")
                    // TODO
                } else if (index === 1) {
                    if(debug) console.log("Choosing existing file...")
                    if(!fileDialogLoader.active)
                        fileDialogLoader.active = true
                    fileDialogLoader.item.chooseImageFile()
                }
            }

            onClicked: {
                root.showListViewPage({
                                          "title": qsTr("Photo menu:"),
                                          "model": [qsTr("Take a picture"), qsTr("Choose existing picture...")],
                                          "okFunction": selectMenu
                                      })
            }
        }

        Rectangle {
            id: phonesRect
            x: backgroundItem.horizontal ? parent.width * 0.5 + backgroundItem.margin : 0
            y: backgroundItem.horizontal ? 0 : parent.height * 0.5 + backgroundItem.margin
            width: backgroundItem.horizontal ? parent.width * 0.5 - backgroundItem.margin : parent.width
            height: backgroundItem.horizontal ? parent.height : parent.height * 0.5 - backgroundItem.margin
            color: styles.colors.white
        }

        FlyInnerShadow { target: phonesRect }

        FlyContactPropertyList {
            id: contactPropertyList
            anchors { fill: phonesRect; leftMargin: 10 * dpiRatio; rightMargin: anchors.leftMargin }
        }
    }
}
