import QtQuick 2.3

FocusScope {
    id: contactList

    property bool emptyList: (contactsListView.list.count === 0)
    property var  model: []  // should provide idString, name, phones, emails, customData
    property bool showPhones: true // if not then emails
    property bool popupMode: true
    property bool chooseOnePhone: false
    property bool showContactInfoViaPhotoClick: false
    signal clicked(string i, string n, string p, string c)

    width: parent.width; height: centerRect.height * 0.5
    visible: !popupMode
    enabled: visible
    z: 1000

    function show(buttonClicked) {
        contactsListView.list.contentY = 0
        visible = buttonClicked ? true : Qt.binding(function() { return !contactList.emptyList } )
    }

    function hide() {
        visible = false
    }

    MouseArea {
        x: root.currentPage ? -mapToItem(root.currentPage, 0, 0).x : 0
        y: root.currentPage ? -mapToItem(root.currentPage, 0, 0).y : 0
        width: root.width; height: root.height
        enabled: contactList.popupMode
        onClicked: contactList.hide()
    }

    FlyShadow { target: listRect; horizontalOffset: -2; verticalOffset: 2; visible: contactList.popupMode }
    Rectangle {
        id: listRect
        anchors.fill: parent
        color: contactList.popupMode ? styles.colors.white : "transparent"
        border { color: Qt.darker(color); width: 1 }
        radius: contactList.popupMode ? 2 * dpiRatio : 0

        FlyListView {
            id: contactsListView
            anchors.fill: parent; anchors.margins: 1
            borderWidth: contactList.popupMode ? 0 : 1
            list.model: contactList.model
            list.currentIndex: -1
            list.delegate: Item {
                id: listItem

                property var dataList: contactList.showPhones ? contact.phoneList : contact.emailList

                width: contactsListView.width; height: root.itemHeight * 1.5
                clip: true

                FlyTouchAnimation { mouseArea: listItemMouseArea }

                FlyColoredImage {
                    id: attachImage
                    x: parent.height * 0.1; width: height; height: parent.height * 0.8
                    anchors.verticalCenter: parent.verticalCenter
                    pressed: photoMouseArea.enabled ? photoMouseArea.pressed : listItemMouseArea.pressed
                    imagePath: "image://ContactImageProvider/" + contact.id
                }

                FlyLabel {
                    id: listItemWhoLabel
                    anchors { left: attachImage.right; top: parent.top; bottom: parent.verticalCenter
                        leftMargin: parent.height * 0.1 }
                    width: Math.min(implicitWidth, parent.width - x)
                    text: name
                    font.pixelSize: styles.label.big; fontSizeMode: Text.FixedSize;
                    verticalAlignment: Text.AlignVCenter
                    elide: Text.ElideRight
                }

                FlyLabel {
                    anchors { left: attachImage.right; top: parent.verticalCenter; bottom: parent.bottom
                        leftMargin: parent.height * 0.1 }
                    width: Math.min(implicitWidth, parent.width - x)
                    text: dataList.join(", ")
                    font.pixelSize: styles.label.smallest; fontSizeMode: Text.FixedSize;
                    verticalAlignment: Text.AlignVCenter
                    elide: Text.ElideRight
                }

                FlySeparator { anchors.bottom: parent.bottom }

                MouseArea {
                    id: listItemMouseArea
                    anchors.fill: parent
                    onClicked: {
                        if(dataList.length > 1) {
                            if(contactList.popupMode || contactList.chooseOnePhone) {
                                root.showListViewPage({ "title": qsTr("Choose item:"),
                                                          "model": dataList,
                                                          "okFunction": function(i) { contactList.clicked(idString, name, dataList[i], customData);
                                                              if(contactList.popupMode) contactList.hide() } })
                            } else {
                                contactList.clicked(idString, name, "", "")
                            }
                        } else {
                            contactList.clicked(idString, name, dataList, customData)

                            if(contactList.popupMode)
                                contactList.hide()
                        }
                    }
                }

                MouseArea {
                    id: photoMouseArea
                    anchors { left: parent.left; top: parent.top; right: listItemWhoLabel.left; bottom: parent.bottom }
                    enabled: contactList.showContactInfoViaPhotoClick
                    onClicked: root.showContactShortInfoPage(idString)
                }
            }
        }
    }

    FlyLabel {
        anchors.centerIn: parent
        text: qsTr("Contacts not found.")
        font.pixelSize: styles.label.big
        visible: contactList.emptyList
    }
}
