import QtQuick 2.3

Item {
    id: controlButton

    property alias image: image
    property alias text: txt.text
    property alias textColor: txt.color
    property alias fontSize: txt.font.pixelSize
    property alias pressAndHoldText: pressAndHoldLabel.text

    property bool canBeOff: false
    property bool on: true

    readonly property color whiteColor: styles.colors.white
    readonly property color lightColor: styles.highlightColor
    readonly property color darkColor: styles.colors.whiteC

    signal clicked
    signal pressAndHold

    width: height; height: parent.height
    enabled: (opacity === 0 || !visible) ? false : true

    Rectangle {
        id: toolTipRect
        width: pressAndHoldLabel.paintedWidth + 30 * dpiRatio; height: root.itemHeight * 0.8
        anchors { bottom: parent.top; bottomMargin: 20 * dpiRatio; horizontalCenter: parent.horizontalCenter }
        border { width: 1; color: darkColor }
        radius: 6 * dpiRatio
        color: lightColor
        visible: pressAndHoldLabel.text && mouseArea.wasHeld && mouseArea.containsMouse

        FlyLabel {
            id: pressAndHoldLabel
            anchors.centerIn: parent
            font.pixelSize: parent.height * 0.6
            color: whiteColor
        }
    }

    Rectangle {
        anchors.fill: parent; anchors.margins: -parent.width * 0.1
        radius: width / 2
        color: lightColor
        opacity: controlButton.on ? 1.0 : 0
        transform: Scale {
            origin.x: mouseArea.mouseX + Math.abs(anchors.margins);
            origin.y: mouseArea.mouseY + Math.abs(anchors.margins);
            xScale: controlButton.on ? 1.0 : 0
            yScale: xScale
            Behavior on xScale { NumberAnimation { } }
        }
        Behavior on opacity { NumberAnimation { } }
    }

    FlyTouchAnimation {
        isRect: false;
        mouseArea: mouseArea;
        backColor: controlButton.on ? root.getColorString(0x33, styles.colors.white) : root.getColorString(0x66, styles.highlightColor);
        frontColor: controlButton.on ? root.getColorString(0x44, styles.colors.white) : styles.highlightColor;
    }

    FlyColoredImage {
        id: image
        anchors { left: parent.left; top: parent.top; right: parent.right; bottom: txt.visible ? txt.top : parent.bottom; margins: 5 * dpiRatio }
        imageFillMode: Image.PreserveAspectFit
        imageColorEnabled: canBeOff ? true : false
        imageColor: controlButton.on ? "transparent" : darkColor

        Behavior on imageColor { ColorAnimation { } }
    }

    FlyLabel {
        id: txt
        anchors { left: parent.left; right: parent.right; bottom: parent.bottom; margins: 5 * dpiRatio }
        height: parent.height * 0.225
        text: ""
        font.pixelSize: height; elide: Text.ElideRight
        font.bold: true; minimumPixelSize: parent.height * 0.15; fontSizeMode: Text.HorizontalFit
        horizontalAlignment: Text.AlignHCenter; verticalAlignment: Text.AlignVCenter
        visible: text !== ""
        color: controlButton.on ? whiteColor : darkColor
    }

    MouseArea {
        id: mouseArea

        property bool wasHeld: false

        anchors.fill: parent
        onClicked: controlButton.clicked()
        onPressAndHold: wasHeld = true
        onCanceled: wasHeld = false
        onReleased: {
            wasHeld = false
            if(mouse.wasHeld && containsMouse)
                controlButton.pressAndHold()
        }
    }
}
