import QtQuick 2.3

FocusScope {
    id: lineEdit

    property alias text: inputText.text
    property alias placeholderText: inputTextPlaceholder.text
    property bool showClearButton: true
    property bool showRectangles: true

    property alias inputMethodHints: inputText.inputMethodHints
    property alias regExp: regExpValidator.regExp
    property alias echoMode: inputText.echoMode
    property alias textColor: inputText.color
    property alias placeholderTextColor: inputTextPlaceholder.color
    property alias fontPixelSize: inputText.font.pixelSize
    property alias verticalAlignment: inputText.verticalAlignment
    property alias horizontalAlignment: inputText.horizontalAlignment
    property alias inputText: inputText
    property real  contentWidth: inputText.contentWidth + clearRect.width
    property int   accessibleRole: Accessible.EditableText
    property int   passwordMaskDelay: 1000

    signal backspaceClickedOnEmptyText
    signal enterClicked

    width: 500; height: root.itemHeight
    clip: true

    // TODO HOT: add EnterKeyAction alias; see http://doc.qt.io/QtVirtualKeyboard/qtvirtualkeyboard-enterprise-virtualkeyboard-virtualkeyboard-content-textfield-qml.html

    TextInput {
        id: inputText
        x: 15 * dpiRatio
        width: parent.width - x - clearRect.width; height: parent.height * 0.9
        font.pixelSize: styles.label.small
        verticalAlignment: TextInput.AlignBottom
        color: styles.lineedit.textColor
        selectByMouse: !tabletMode
        focus: true
        validator: RegExpValidator { id: regExpValidator }
        Accessible.role: lineEdit.accessibleRole
        Accessible.name: "Text"
        Accessible.editable: true
        clip: true
        onAccepted: lineEdit.enterClicked()

        Binding {
            target: inputText
            property: "passwordMaskDelay"
            value: lineEdit.passwordMaskDelay
            when: inputText.hasOwnProperty("passwordMaskDelay")
        }

        FlyLabel {
            id: inputTextPlaceholder
            anchors.fill: parent
            text: ""
            color: styles.lineedit.placeholderColor
            visible: (inputText.displayText === "")
            font {
                italic: true
                pixelSize: inputText.font.pixelSize;
            }
            verticalAlignment: TextInput.AlignBottom
        }

        Keys.onPressed: {
            if ((event.key === Qt.Key_Backspace) && (text === "")) {
                lineEdit.backspaceClickedOnEmptyText()
            }
        }
    }

    property real hor: /*tabletMode ? 2 :*/ 1
    property real ver: /*tabletMode ? 10 :*/ 7

    Rectangle {
        id: clearRect
        anchors { right: rightRect.left; bottom: parent.bottom; bottomMargin: parent.height * 0.1 }
        width: showClearButton ? parent.height * 0.8 : 15; height: width
        opacity: (inputText.text === "" ? 0.0 : 1.0)
        color: "transparent"
        visible: showClearButton; enabled: visible
        FlyLabel { anchors.centerIn: parent; text: "\u2717"; color: textColor; font.pixelSize: inputText.height * 0.6 }
        MouseArea { anchors.fill: parent; onClicked: inputText.text = "" }
        Behavior on opacity { NumberAnimation {} }
    }

    Rectangle {
        id: leftRect
        anchors { left: parent.left; leftMargin: 1; bottom: parent.bottom }
        width: hor; height: ver; color: lineEdit.activeFocus ? styles.highlightColor : styles.lineedit.borderColor
        visible: showRectangles
    }
    Rectangle {
        anchors { left: leftRect.left; bottom: parent.bottom; right: rightRect.right }
        height: hor; color: lineEdit.activeFocus ? styles.highlightColor : styles.lineedit.borderColor
        visible: showRectangles
    }
    Rectangle {
        id: rightRect
        anchors { right: parent.right; bottom: parent.bottom }
        width: hor; height: ver; color: lineEdit.activeFocus ? styles.highlightColor : styles.lineedit.borderColor
        visible: showRectangles
    }
}
