import QtQuick 2.3

Rectangle {
    id: button

    property alias image: image
    property alias text: txt.text
    property alias textColor: txt.color
    property alias fontSize: txt.font.pixelSize
    property bool  checked: false
    property real  margin: 10 * dpiRatio
    property real  imageMarginRatio: 0.7
    property color pressColor: root.getColorString(0x33, styles.colors.gray9)

    signal clicked
    signal pressAndHold

    width: buttonRow.width + margin * 2; height: parent.height
    color: "transparent"
    enabled: (opacity === 0 || !visible) ? false : true

    Rectangle {
        anchors.centerIn: buttonRow
        width: parent.width * 0.9; height: parent.height * 0.9
        border { width: mouseArea.pressed || button.checked ? 1 : 0; color: root.getColorString(0x55, styles.colors.gray9) } radius: 4 * dpiRatio
        color: mouseArea.pressed || button.checked ? button.pressColor : "transparent"
    }

    Row {
        id: buttonRow
        x: margin
        height: parent.height
        spacing: button.margin

        FlyColoredImage {
            id: image
            anchors.verticalCenter: parent.verticalCenter
            width: height; height: parent.height * button.imageMarginRatio
            pressed: mouseArea.pressed || button.checked
        }

        FlyLabel {
            id: txt
            anchors.verticalCenter: parent.verticalCenter
            text: ""
            font.pixelSize: parent.height * 0.5
            transformOrigin: Item.Bottom
            scale: mouseArea.pressed || button.checked ? 0.95 : 1.0
            visible: text !== ""
        }
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        onClicked: button.clicked()
        onPressAndHold: button.pressAndHold()
    }
}
