import QtQuick 2.3

Item {
    id: notificationItem
    width: parent.ListView.view.width; height: root.itemHeight * 2
    clip: true // for touch animation

    readonly property alias icon: icon
    readonly property alias caption: caption
    readonly property alias description: description
    readonly property alias mouseArea: mouseArea
    property real margin: parent.height * 0.1

    FlyTouchAnimation { mouseArea: mouseArea }

    FlyColoredImage {
        id: icon
        x: margin; y: margin
        width: parent.height * 0.8; height: width
        imageFillMode: Image.PreserveAspectFit
        imagePath: _dataMap["icon"] ? _dataMap["icon"] : "image://ThemeImageProvider/task-attention"
    }

    FlyLabel {
        id: caption
        x: icon.x + icon.width + margin; y: 0
        width: parent.width - x - margin; height: parent.height * 0.5
        text: _dataMap["caption"] ? _dataMap["caption"] : ""
        font.pixelSize: height * 0.55; fontSizeMode: Text.FixedSize;
        verticalAlignment: Text.AlignBottom
        elide: Text.ElideRight
    }

    FlyLabel {
        id: description
        x: icon.x + icon.width + margin; y: parent.height * 0.5
        width: parent.width - x - margin; height: parent.height * 0.5
        text: _dataMap["description"] ? _dataMap["description"] : caption.text
        font.pixelSize: height * 0.4; fontSizeMode: Text.FixedSize;
        color: styles.label.colorDisabled
        verticalAlignment: Text.AlignTop
        elide: Text.ElideRight
    }

    MouseArea {
        id: mouseArea;
        anchors.fill: parent;
        drag {
            target: _removable ? notificationItem : undefined
            axis: Drag.XAxis
        }
        onReleased: {
            if(!drag.active) return

            if((notificationItem.x > notificationItem.width * 0.4) || (notificationItem.x < -notificationItem.width * 0.4)) {
                _removeNotification()
            } else if(notificationItem.x !== 0) {
                returnToOrigPosAnimation.start()
            }
        }
        onClicked: notificationItem.parent.ListView.view.onNotificationClicked()
    }

    NumberAnimation {
        id: returnToOrigPosAnimation
        target: notificationItem; property: "x"; to: 0
    }
}
