import QtQuick 2.3
import QtQuick.Window 2.2
import Fly.Components 1.0

FlyMain {
    id: root
    width: tabletMode ? Screen.width : root.minimumWidth
    height: tabletMode ? Screen.height : root.minimumHeight

    readonly property real  itemHeight: 50 * dpiRatio
    readonly property real  pageMargin: tabletMode ? 0 : 0.10 / dpiRatio
    readonly property alias styles: styles

    property FlyPageStack   customPageStack: null

    readonly property var   addFunctionToBackStack: customPageStack ? customPageStack.addFunctionToBackStack : flyPageStack.addFunctionToBackStack
    readonly property var   popFunctionFromBackStack: customPageStack ? customPageStack.popFunctionFromBackStack : flyPageStack.popFunctionFromBackStack
    readonly property var   clearBackStack: customPageStack ? customPageStack.clearBackStack : flyPageStack.clearBackStack

    readonly property var   addPage: customPageStack ? customPageStack.push : flyPageStack.push
    readonly property var   removePage: customPageStack ? customPageStack.pop : flyPageStack.pop
    readonly property var   currentPage: customPageStack ? customPageStack.currentItem : flyPageStack.currentItem
    property alias          initialPage: flyPageStack.initialPage

    readonly property var locale: Qt.locale()
    readonly property var virtualKeyboard: qtVkbdInstalled
                                           ? Qt.createQmlObject("import QtQuick 2.3; FlyVirtualKeyboard {}", root, "dynamicVkbd")
                                           : null

    // TODO move functions somewhere

    function showMessagePage(properties) { // properties: title, message
        root.addPage(Qt.resolvedUrl("FlyMessagePage.qml"), properties)
    }

    function showListViewPage(properties) { // properties: title, model, okFunction
        root.addPage(Qt.resolvedUrl("FlyListViewPage.qml"), properties)
    }

    function showSpinBoxPage(properties, minValue, maxValue, curVal) { // properties: title, selectFunction
        root.addPage(Qt.resolvedUrl("FlySpinBoxPage.qml"), properties)
        root.currentPage.init(minValue, maxValue, curVal)
    }

    function showContactShortInfoPage(contactId) {
        if(showContactShortInfoPage.busy) // TODO: do it for all functions
            return

        showContactShortInfoPage.busy = true
        root.addPage(Qt.resolvedUrl("FlyContactShortInfoPage.qml"))
        root.currentPage.init(db.getContact(contactId, SqliteDatabase.PhoneContactsDataType))
        root.currentPage.onEnabledChanged.connect( function() { if(root.currentPage.enabled) showContactShortInfoPage.busy = false } )
    }

    function showContactFullInfoPage(properties, contactId, contactText) { // properties: title, confirmFunction
        root.addPage(Qt.resolvedUrl("FlyContactFullInfoPage.qml"), properties)
        root.currentPage.init((contactId ? db.getContact(contactId, SqliteDatabase.FullContactsDataType) : null), contactText)
    }

    function showContactListPage(properties) { // properties: title, model, okFunction
        root.addPage(Qt.resolvedUrl("FlyContactListPage.qml"), properties)
    }

    function showCalendar(properties) { // properties: title, currentDayChange, startDate, selectFunction
        root.addPage(Qt.resolvedUrl("FlyCalendarPage.qml"), properties)
    }

    function showLineEditPage(properties) { // properties: title, line.text, line.placeholderText, selectFunction
        root.addPage(Qt.resolvedUrl("FlyLineEditPage.qml"), properties)
    }

    function showColorPicker(properties) { // properties: selectFunction, colorArray
        root.addPage(Qt.resolvedUrl("FlyColorPickerPage.qml"), properties)
    }

    function getRandomInt(min, max) { // TODO move to utils.js
        return Math.floor(Math.random() * (max - min + 1)) + min;
    }

    Item {
        id: container
        anchors { left: parent.left; top: parent.top; right: parent.right }
        height: virtualKeyboard ? virtualKeyboard.y : root.height // removed anchors.bottom because of ORIENTATION BUG

        FlyPageStack {
            id: flyPageStack
            anchors.fill: parent
        }

        FlyStyle { id: styles }
    }

    onClosing: flyPageStack.processBackClick()

    Component.onCompleted: {
        initializeImageProvider()

        visible = true

        console.assert(initialPage, "Error! initialPage undefined!")
        flyPageStack.push("initialPage")
    }
}
