import QtQuick 2.3

FlySettingsItem {
    id: settingsItem

    // for main page
    property var childListViewItem: null
    property var name: itemData.name
    property var icon: itemData.icon
    property var iconColor: itemData.iconColor

    contentItem.width: width - label.width
    mouseArea.onClicked: {
        listViewLoader.active = true
        parent.ListView.view.childListViewItem = settingsItem
        root.addFunctionToBackStack(closeListView)
    }

    function closeListView() {
        if(listViewLoader.item) listViewLoader.item.closeAnimation.start()
        parent.ListView.view.childListViewItem = null
        root.popFunctionFromBackStack()
    }

    Connections {
        target: parent.ListView.view
        onCloseAllChildLists: listViewLoader.active = false;
    }

    FlyLabel {
        id: label
        anchors { top: parent.top; right: parent.right; bottom: parent.bottom; bottomMargin: parent.height * 0.1}
        width: parent.height * 0.5
        text: '\u232a'
        font.pixelSize: height * 0.4
        color: styles.label.colorDisabled
        horizontalAlignment: Text.AlignHCenter; verticalAlignment: Text.AlignVCenter
    }

     // TODO incorrent russian translation
    FlySettingsItemData {
        id: itemBack;
        name: qsTr("..back");
        description: qsTr("Return back to ") + itemData.returnBackTo
        clickFunc: closeListView
    }

    Loader {
        id: listViewLoader
        x: settingsItem.parent.ListView.view.x; y: settingsItem.parent.ListView.view.y
        width: settingsItem.parent.ListView.view.width; height: settingsItem.parent.ListView.view.height
        parent: settingsItem.parent.ListView.view.parent
        active: false
        sourceComponent: Component {
            Item {
                id: listViewItem
                property alias closeAnimation: closeAnimation

                Rectangle {
                    id: listViewRect
                    anchors.fill: parent
                    color: listViewLoader.parent.centerRectShadow ? styles.page.centerRectColor : styles.page.foregroundColor

                    FlySettingsListView {
                        anchors.fill: parent
                        model: [itemBack].concat(itemData.model)
                        currentIndex: 0
                        onChildListViewItemChanged: {
                            settingsItem.childListViewItem = childListViewItem
                            settingsItem.parent.ListView.view.childListViewItemChanged()
                        }
                    }
                }
                FlyInnerShadow { target: listViewRect; visible: listViewRect.color === styles.page.centerRectColor; enabled: visible }

                NumberAnimation on x { from: width; to: 0; easing.type: Easing.InCubic }
                SequentialAnimation {
                    id: closeAnimation
                    NumberAnimation { target: listViewItem; property: "x"; to: listViewItem.width; easing.type: Easing.InCubic }
                    ScriptAction { script: (function() { listViewLoader.active = false; })() }
                }
            }
        }
    }
}
