import QtQuick 2.3

FocusScope {
    id: textEdit

    property alias text: text.text
    property alias placeholderText: textEditPlaceholder.text
    property alias textColor: text.color
    property alias textSize: text.font.pixelSize
    property alias textFormat: text.textFormat
    property alias readOnly: text.readOnly

    function setFocus() {
        text.forceActiveFocus()
    }

    Flickable {
        id: textEditFlickable
        anchors { fill: parent; margins: 10 }
        flickableDirection: Flickable.VerticalFlick
        contentHeight: text.contentHeight
        clip: true

        TextEdit {
            id: text
            width: textEditFlickable.width
            height: Math.max(contentHeight, textEditFlickable.height)
            color: styles.lineedit.textColor
            font.pixelSize: styles.label.small
            wrapMode: Text.Wrap
            textFormat: TextEdit.PlainText
            selectByMouse: !tabletMode
            focus: true

            Accessible.role: Accessible.EditableText
            Accessible.multiLine: true
            Accessible.name: "Text"

            FlyLabel {
                id: textEditPlaceholder
                anchors.fill: parent; anchors.leftMargin: 5
                text: ""
                color: styles.lineedit.placeholderColor
                visible: (text.text === "" && !text.activeFocus)
                font {
                    italic: true
                    pixelSize: text.font.pixelSize;
                }
                verticalAlignment: TextInput.AlignTop
            }

            onLinkActivated: {
                if(debug) console.log("Opening url:", link);

                Qt.openUrlExternally(link)
            }

            onCursorPositionChanged: {
                if(contentHeight < textEditFlickable.height)
                    return

                if(cursorRectangle.y < textEditFlickable.contentY) {
                    textEditFlickable.contentY = cursorRectangle.y
                } else if(cursorRectangle.y + cursorRectangle.height > textEditFlickable.contentY + textEditFlickable.height) {
                    textEditFlickable.contentY = cursorRectangle.y + cursorRectangle.height - textEditFlickable.height
                }
            }

            MouseArea {
                anchors.fill: parent
                cursorShape: parent.hoveredLink ? Qt.PointingHandCursor : Qt.ArrowCursor
                acceptedButtons: Qt.NoButton
            }
        }
    }

    FlyScrollBar {
        anchors.fill: parent
        contentItem: textEditFlickable
    }
}
