import QtQuick 2.3

Rectangle {
    id: touchAnimation

    property bool isRect: true
    property MouseArea mouseArea: null

    property color backColor: styles.touchAnimation.back
    property color frontColor: styles.touchAnimation.front

    anchors.fill: parent; anchors.margins: isRect ? 0 : -parent.width * 0.1
    color: backColor
    radius: isRect ? 0 : width / 2
    opacity: 0

    function startAnimation() {
        touchAnimationEnd.stop();

        touchRect.x = mouseArea.mouseX + Math.abs(touchAnimation.anchors.margins)
        touchRect.y = mouseArea.mouseY + Math.abs(touchAnimation.anchors.margins)
        touchRect.opacity = 1.0;
        touchAnimation.opacity = 1.0;
        touchAnimationStart.start()
    }

    function endAnimation() {
        touchAnimationStart.stop();
        touchAnimationEnd.start()
    }

    function cancelAnimation() {
        if(startAnimationTimer.running) {
            startAnimationTimer.stop();
        } else {
            endAnimation();
        }
    }

    Timer { // if someone steals mouse event we need to stop timer
        id: startAnimationTimer
        interval: 100
        onTriggered: startAnimation()
    }

    Rectangle {
        id: touchRect
        height: width
        color: frontColor
        radius: width / 2
        opacity: 0

        ParallelAnimation {
            id: touchAnimationStart
            NumberAnimation { target: touchRect; property: "x"; to: 0; easing.type: Easing.InQuad; duration: 1000 }
            NumberAnimation { target: touchRect; property: "y"; to: isRect ? -touchAnimation.width / 2 + touchAnimation.height / 2 : 0;
                easing.type: Easing.InQuad; duration: 1000 }
            NumberAnimation { target: touchRect; property: "width"; from: 1; to: touchAnimation.width; easing.type: Easing.InQuad; duration: 1000 }
        }

        ParallelAnimation {
            id: touchAnimationEnd
            NumberAnimation { target: touchRect; property: "x"; to: 0; easing.type: Easing.OutQuad; duration: 500 }
            NumberAnimation { target: touchRect; property: "y"; to: isRect ? -touchAnimation.width / 2 + touchAnimation.height / 2 : 0;
                easing.type: Easing.OutQuad; duration: 500 }
            NumberAnimation { target: touchRect; property: "width"; to: touchAnimation.width; easing.type: Easing.OutQuad; duration: 500 }
            NumberAnimation { target: touchRect; property: "opacity"; to: 0; easing.type: Easing.InQuad; duration: 500 }
            NumberAnimation { target: touchAnimation; property: "opacity"; to: 0; easing.type: Easing.InQuad; duration: 500 }
        }
    }

    Connections {
        property bool animating: false
        target: mouseArea
        onPressed: { animating = true; startAnimationTimer.start() }
        onReleased: {
            animating = false;
            if(startAnimationTimer.running) {
                startAnimationTimer.stop();
                startAnimation();
            }
            endAnimation();
        }
        onCanceled: { animating = false; cancelAnimation(); }
        onPositionChanged: if(animating && mouseArea.drag.active) { animating = false; cancelAnimation(); }
    }
}
