import QtQuick 2.3
import QtQuick.Window 2.2
import Fly.Components 1.0

CustomWindow {
    id: window
    x: 0; y: root.statusBarHeight
    width: root.width; height: root.height
    minimumHeight: root.minimumHeight; maximumHeight: root.maximumHeight
    minimumWidth: root.minimumWidth; maximumWidth: root.maximumWidth
    color: "transparent"
    flags: Qt.FramelessWindowHint
    visible: false

    property alias flyPageStack: flyPageStack
    property alias initialPage: flyPageStack.initialPage

    function appear() {
        show()
        raise()
    }

    function disappear() {
        disappearAnim.start()
    }

    Connections { // TODO should connect to dbus, not root
        target: root
        onCloseChildWindow: if(wid === windowId) { flyPageStack.clearBackStack(); window.hide() }
    }

    Timer { // ORIENTATION BUG
        id: contentItemGeometryUpdate
        interval: 1000
        onTriggered: {
            if(contentItem) {
                if(contentItem.width !== width) contentItem.width = width
                if(contentItem.height !== height) contentItem.height = height
            }
        }
    }

    FlyPageStack { id: flyPageStack; anchors.fill: parent; isMain: false; enabled: window.opacity >= 1.0 }

    NumberAnimation { id: appearAnim; target: window; property: "opacity"; from: 0; to: 1.0; duration: 400 }
    SequentialAnimation {
        id: disappearAnim
        NumberAnimation { target: window; property: "opacity"; from: 1.0; to: 0; duration: 400 }
        ScriptAction { script: (function() { flyPageStack.clearBackStack(); window.hide() })() }
    }

    onVisibleChanged: {
        if(visible) appearAnim.start()
    }

    onActiveChanged: {
        if(active && visible) { // sometimes, when window hides, active become true
            root.customPageStack = flyPageStack
            if(root.virtualKeyboard) root.virtualKeyboard.parent = contentItem
        } else {
            root.customPageStack = null
            if(root.virtualKeyboard) root.virtualKeyboard.parent = root.contentItem
        }
    }

    onClosing: {
        if(flyPageStack.backStackFunctions.length === 0) {
            root.customPageStack = null
            if(root.virtualKeyboard) root.virtualKeyboard.parent = root.contentItem
            disappear()
        } else {
            flyPageStack.processBackClick()
        }
    }

    Screen.onPrimaryOrientationChanged: contentItemGeometryUpdate.restart() // ORIENTATION BUG

    Component.onCompleted: {
        console.assert(initialPage, "Error! initialPage undefined!")

        flyPageStack.push("initialPage")
    }
}
